@@ -1,9 +1,12 @@
+import os
 import pandas as pd
 from math import sin, cos
 from ColorController.conversions import hex_to_rgb, colorsys_hsv_to_hsv360, hsv360_to_hsvdistance
 import colorsys
 
-colors_df = pd.read_csv(r'colornames.txt', delimiter=" ", skiprows=60, header=None)
+CURRENT_DIR = os.path.dirname(__file__)
+
+colors_df = pd.read_csv(os.path.join(CURRENT_DIR, 'colornames.txt'), delimiter=" ", skiprows=60, header=None)
 
 
 
